Learn R Programming

Tex4exams (version 0.1.2)

rfracF: Convert a decimal into TeX code of vertical fractions with the sign in front of the fraction

Description

The function converts a decimal into TeX code of vertical fractions, using functions 'denominators' and 'numerators' from the packaege 'fractional'. This function differs from 'rfrac' only in the place of the negative signs. 'rfracF' returns the fraction with the sign in front.

Usage

rfracF(x)

Value

The function returns a string of tex code for the number in vertical fraction form with the sign in front of the fraction.

Arguments

x

a list of decimal numbers.

See Also

mfrac,smfrac, rfrac

Examples

Run this code
x <-  sample(c(1:55),1)/100
rfrac(x)

Run the code above in your browser using DataLab