rfracF: Convert a decimal into TeX code of vertical fractions with the sign in front of the fraction
Description
The function converts a decimal into TeX code of vertical fractions, using functions 'denominators' and 'numerators' from the packaege 'fractional'. This function differs from 'rfrac' only in the place of the negative signs. 'rfracF' returns the fraction with the sign in front.
Usage
rfracF(x)
Value
The function returns a string of tex code for the number in vertical fraction form with the sign in front of the fraction.